<?php
/*
Plugin Name: WPnet.pl - Hidden Text
Plugin URI: https://wpnet.pl/blog/wtyczki/wtyczka-wpnet-pl-hidden-text/
Version: 1.0
Author: WPnet.pl
Author URI: https://wpnet.pl
License: GPL2
*/

/* Make sure we don't expose any info if called directly */
if ( !function_exists( 'add_action' ) ) {
	exit;
}

/**
 * WPnet.pl Templates Class.
 */
class WPnet_Hidden_Text {

	/**
	 * Hook into the appropriate actions when the class is constructed.
	 */
    public function __construct() {
		add_action( 'init', array( $this, 'load_textdomain' ) );
		add_shortcode( 'hidden-text', array( $this, 'add_hidden_text_shortcode' ) );
		add_shortcode( 'ht', array( $this, 'add_hidden_text_shortcode' ) );
		add_action( 'wp_head', array( $this, 'add_head' ) );
    }

	/**
	 * Load plugin textdomain.
	 */
	public function load_textdomain() {
		load_plugin_textdomain( 'wpnet-hidden-text', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Add shortcode.
	 */
	function add_hidden_text_shortcode( $atts ) {
		$atts = shortcode_atts( array(
			'visible' => __( 'Visible text', 'wpnet-hidden-text' ),
			'hidden'  => __( '-Hidden text', 'wpnet-hidden-text' ),
			'label'   => __( 'View', 'wpnet-hidden-text' ),
			'message' => '',
			'id'      => '',
			'v'       => '',
			'h'       => '',
			'l'       => '',
			'm'       => '',
		), $atts, 'hidden-text' );

		$v = ( '' !== $atts['v'] ) ? $atts['v'] : $atts['visible'];
		$h = ( '' !== $atts['h'] ) ? $atts['h'] : $atts['hidden'];
		$l = ( '' !== $atts['l'] ) ? $atts['l'] : $atts['label'];
		$m = ( '' !== $atts['m'] ) ? $atts['m'] : $atts['message'];

		return '<span class="wpnet-hidden-text"><span class="visible-text">' . $v . '</span><span class="hidden-text">' . $h . '</span> <span class="message">' . $m . '</span> <a id="' . $atts['id'] . '" href="#" class="view-hidden-text">' . $l . '</a></span>';
	}

	/**
	 * Add styles and script.
	 */

	function add_head() { ?>
		<style>
		.wpnet-hidden-text > .hidden-text,
		.wpnet-hidden-text > .message {
			display: none;
		}
		</style>

		<script>
		document.addEventListener( 'DOMContentLoaded', function() {
			document.querySelectorAll( '.wpnet-hidden-text' ).forEach( hiddenText => {
				hiddenText.addEventListener( 'click', (e) => {
					e.preventDefault();
					hiddenText.querySelector( '.view-hidden-text' ).style.display = 'none';
					hiddenText.querySelector( '.hidden-text' ).style.display = 'initial';
					hiddenText.querySelector( '.message' ).style.display = 'initial';
				} );
			} )
		} );
		</script>
	<?php
	}
}
new WPnet_Hidden_Text();
